/***************************************************************************
  This is a library for the BME280 humidity, temperature & pressure sensor

  Designed specifically to work with the Adafruit BME280 Breakout
  ----> http://www.adafruit.com/products/2650

  These sensors use I2C or SPI to communicate, 2 or 4 pins are required
  to interface. The device's I2C address is either 0x76 or 0x77.

  Adafruit invests time and resources providing this open source code,
  please support Adafruit andopen-source hardware by purchasing products
  from Adafruit!

  Written by Limor Fried & Kevin Townsend for Adafruit Industries.
  BSD license, all text above must be included in any redistribution
 ***************************************************************************/

#include <Wire.h>
#include <SPI.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>

#define BME_SCK 13
#define BME_MISO 12
#define BME_MOSI 11
#define BME_CS 10

#define SEALEVELPRESSURE_HPA (1013.25)

float TempInC = 0.0;
float TempInF = 0.0;
float Pressure = 0.0;
float Humidity = 0.0;

//Adafruit_BME280 bme; // I2C
//Adafruit_BME280 bme(BME_CS); // hardware SPI
Adafruit_BME280 bme(BME_CS, BME_MOSI, BME_MISO, BME_SCK); // software SPI

unsigned long delayTime;

void setup() {
    Serial.begin(9600);
    // Serial.println(F("BME280 test"));

    bool status;
    
    // default settings
    // (you can also pass in a Wire library object like &Wire2)
    status = bme.begin();  
    if (!status) {
        Serial.println("Could not find a valid BME280 sensor, check wiring!");
        while (1);
    }
    
   // Serial.println("-- Default Test --");
    delayTime = 1000;

   // Serial.println();
}


void loop() { 
    WeatherVals();
    printValues();
    delay(delayTime);
}

void WeatherVals() {
  TempInC = bme.readTemperature();
  TempInF = ((TempInC * 1.8) + 32);
  Pressure = (bme.readPressure() / 100.0F);
  Humidity = bme.readHumidity();
}

void printValues() {

    /* String WeatherData[] = String(TempInF,Pressure,Humidity); 
    Serial.println(WeatherData + '\r');*/
    // Serial.println(TempInF + ',' + Pressure + ',' + Humidity + '\r'); // create string manually
    String WeatherData1 = '<' + String(TempInF, 2) + ' ';
    // String WeatherData2 = WeatherData1;
    String WeatherData2 = WeatherData1 + String(Pressure, 2) + ' ';
    // String WeatherData4 = WeatherData3;
    String WeatherData3 = WeatherData2 + String(Humidity, 0);
    String WeatherData = WeatherData3 + '>';
    Serial.println(WeatherData + '\r');
    /*Serial.print("Temperature = ");
    Serial.print(bme.readTemperature());
    Serial.println(" *C");

    Serial.print("Pressure = ");

    Serial.print(bme.readPressure() / 100.0F);
    Serial.println(" hPa");

    Serial.print("Approx. Altitude = ");
    Serial.print(bme.readAltitude(SEALEVELPRESSURE_HPA));
    Serial.println(" m");

    Serial.print("Humidity = ");
    Serial.print(bme.readHumidity());
    Serial.println(" %");

    Serial.println(); */
}
